/**
 * easyWSDL - easyWSDL toolbox Platform.
 * Copyright (c) 2008,  eBM Websourcing
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.ow2.easywsdl.wsdl.decorator;

import java.util.List;
import java.util.Map;

import javax.xml.namespace.QName;

import org.ow2.easywsdl.schema.api.Documentation;
import org.ow2.easywsdl.schema.api.XmlException;
import org.ow2.easywsdl.schema.api.abstractElmt.AbstractSchemaElementImpl;
import org.ow2.easywsdl.wsdl.api.WSDLElement;
import org.ow2.easywsdl.wsdl.api.WSDLException;
import org.ow2.easywsdl.wsdl.api.abstractElmt.AbstractWSDLElementImpl;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfFault;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfInput;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfOperation;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfOutput;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfOperation.MEPPatternConstants;
import org.w3c.dom.Element;


/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
public class DecoratorOperationImpl<In extends AbsItfInput, Out extends AbsItfOutput, F extends AbsItfFault>  extends AbstractWSDLElementImpl  implements Decorator {

    /**
	 *
	 */
    private static final long serialVersionUID = 1L;

    protected AbsItfOperation<In, Out, F> operation;

    public DecoratorOperationImpl(final AbsItfOperation<In, Out, F> operation) throws WSDLException {
        this.operation = operation;
    }

    public void addFault(final F arg0) {
        this.operation.addFault(arg0);
    }

    public F getFault(final String arg0) {
        return this.operation.getFault(arg0);
    }

    public F getFaultByElementName(final QName arg0) {
        return this.operation.getFaultByElementName(arg0);
    }

    public List<F> getFaults() {
        return this.operation.getFaults();
    }

    public In getInput() {
        return this.operation.getInput();
    }

    public Out getOutput() {
        return this.operation.getOutput();
    }

    public List<String> getParameterOrdering() {
        return this.operation.getParameterOrdering();
    }

    public MEPPatternConstants getPattern() {
        return this.operation.getPattern();
    }

    public QName getQName() {
        return this.operation.getQName();
    }

    public String getSignature() {
        return this.operation.getSignature();
    }

    public F removeFault(final String arg0) {
        return this.operation.removeFault(arg0);
    }

    public F removeFaultByElementName(final QName arg0) {
        return this.operation.getFaultByElementName(arg0);
    }

    public void setInput(final In arg0) {
        this.operation.setInput(arg0);
    }

    public void setOutput(final Out arg0) {
        this.operation.setOutput(arg0);
    }

    public void setParameterOrdering(final List<String> arg0) throws WSDLException {
        this.operation.setParameterOrdering(arg0);
    }

    public void setPattern(final MEPPatternConstants arg0) throws WSDLException {
        this.operation.setPattern(arg0);
    }

    public void setQName(final QName arg0) {
        this.operation.setQName(arg0);
    }

    public Documentation createDocumentation() {
        return this.operation.createDocumentation();
    }

    public Documentation getDocumentation() {
        return this.operation.getDocumentation();
    }

    public Map<QName, String> getOtherAttributes() throws XmlException {
        return this.operation.getOtherAttributes();
    }

    public List<Element> getOtherElements() throws XmlException {
        return this.operation.getOtherElements();
    }

    public void setDocumentation(final Documentation arg0) {
        this.operation.setDocumentation(arg0);
    }

	public F createFault() {
		return this.operation.createFault();
	}

	public In createInput() {
		return this.operation.createInput();
	}

	public Out createOutput() {
		return this.operation.createOutput();
	}

    @Override
	public Object getModel() {
		return ((AbstractWSDLElementImpl)this.operation).getModel();
	}

    @Override
	public AbstractSchemaElementImpl getParent() {
		return ((AbstractWSDLElementImpl)this.operation).getParent();
	}

	public WSDLElement getInternalObject() {
		return this.operation;
	}

}
